use crate::{
    ui::{Board, ReviewTree},
    CoreApi,
};
use glib::Object;
use gtk::{prelude::*, subclass::prelude::*};
use kifu_core::ui::GameReviewView;
use std::{cell::RefCell, rc::Rc};

#[derive(Default)]
pub struct GameReviewPrivate {
    board: Rc<RefCell<Option<Board>>>,
    tree: ReviewTree,
}

#[glib::object_subclass]
impl ObjectSubclass for GameReviewPrivate {
    const NAME: &'static str = "GameReview";
    type Type = GameReview;
    type ParentType = gtk::Box;
}

impl ObjectImpl for GameReviewPrivate {}
impl WidgetImpl for GameReviewPrivate {}
impl BoxImpl for GameReviewPrivate {}

glib::wrapper! {
    pub struct GameReview(ObjectSubclass<GameReviewPrivate>)
        @extends gtk::Box, gtk::Widget,
        @implements gtk::Orientable;
}

impl GameReview {
    pub fn new(api: CoreApi, view: GameReviewView) -> Self {
        let s: Self = Object::builder().build();
        s.set_orientation(gtk::Orientation::Horizontal);

        let review_area = gtk::ScrolledWindow::builder()
            .hscrollbar_policy(gtk::PolicyType::Automatic)
            .vscrollbar_policy(gtk::PolicyType::Automatic)
            .hexpand(true)
            .vexpand(true)
            .build();
        review_area.set_child(Some(&s.imp().tree));
        s.append(&review_area);

        s.imp().tree.set_tree(view.tree);

        s
    }
}
